﻿#This script is intended to be used with Installation Manager 5.8 (or later) on Windows (Windows PowerShell 4 or later).
#####################################################################################################################
###################################

#Requires -Version 4

function LoadInstallationManagerAPI()
{
    if($IsLinux)
    {
        $assemblyPath = "/opt/dspace/common/installationmanager/bin/dSPACE.InstallationManager.API.dll"
        Add-Type -Path $assemblyPath
    }
    elseif($PSVersionTable.PSVersion.Major -le "5")
    {
        [System.Reflection.Assembly]::Load("dSPACE.InstallationManager.API, Version=2.0.0.0, Culture=neutral, PublicKeyToken=f9604847d8afbfbb")
    }
    else
    {
        $assemblyPath = "c:\Windows\Microsoft.NET\assembly\GAC_MSIL\dSPACE.InstallationManager.API\v4.0_2.0.0.0__f9604847d8afbfbb\dSPACE.InstallationManager.API.dll"
        Add-Type -Path $assemblyPath
    }
}

function Add-Path($Path)
{
    $Path = $Path + [IO.Path]::PathSeparator + [Environment]::GetEnvironmentVariable("PATH", "User")
    [Environment]::SetEnvironmentVariable( "Path", $Path, "User")
}

function Remove-Path()
{
    $Path = [Environment]::GetEnvironmentVariable("PATH", "User") + [IO.Path]::PathSeparator + $Path
    $Path = $Path -replace ("C:\\Program Files\\Common Files\\dSPACE\\dSPACE Bus API\\\d{4}-\w{1}\\Deliverables\\bin", "")
    [Environment]::SetEnvironmentVariable( "Path", $Path, "User")
}


#The dSPACE.InstallationManager.API assembly must be loaded. Depending on your intended action, you have to create a ConfigurationInfo or a ConfigurationChange object.
#####################################################################################################################
#################################################

#Load a dSPACE.InstallationManager.API assembly.
LoadInstallationManagerAPI

#Create a ConfigurationInfo object for later use.
$Info=New-Object dSPACE.InstallationManager.API.ConfigurationInfo

#find the dSPACE Bus API installations path
foreach ($installation in $info.Installations)
{
    foreach ($product in $installation.Products)
    {
        if($product -like "dSPACE Bus API*")
        {
            if ($installation.IsActive)
            { 
                "Product: " + $product
                $busApiRootPath = $installation.RootPath
                "dSPACE Bus API Root Path: " + $busApiRootPath
            }
        }
    }
}

if (!$busApiRootPath)
{
    Write-Error("dSPACE Bus API is not installed!")
}

Remove-Path

$busApiBin = $busApiRootPath + "\Deliverables\bin";

#Extend env variable Path wit the path to dSPACE Bus API
Add-Path($busApiRootPath + "\Deliverables\bin")



#This script is intended to be used with Installation Manager 5.8 (or later) on Windows (Windows PowerShell 4 or later).
#####################################################################################################################
########